@@ -21,11 +21,30 @@
 #' 
 #' @details For a 2 x 2 table, where a and d are the concordant cells
 #'          and b and c are discordant cells:
-#'          Odds ratio is the greater of b/c or c/b;
-#'          P is the greater of b/(b+c) or c/(b+c);
+#'          Odds ratio is b/c;
+#'          P is b/(b+c);
 #'          and Cohen's g is P - 0.5.
-#'          These statistics are extended to tables larger
-#'          than 2 x 2.
+#'          
+#'          In the 2 x 2 case, the statistics are directional.
+#'          That is, when cell [1, 2] in the table is greater than
+#'          cell [2, 1], OR is greater than 1, P is greater than 0.5,
+#'          and g is positive.  
+#'          
+#'          In the opposite case, OR is less than 1,
+#'          P is less than 0.5, and g is negative.
+#'          
+#'          In the 2 x 2 case, when the effect is small, the
+#'          confidence interval for OR can pass through 1,
+#'          for g can pass through 0, and for P can pass through 0.5.
+#'          
+#'          For tables larger than 2 x 2, the statistics are not directional.
+#'          That is, OR is always >= 1, P is always >= 0.5, and
+#'          g is always positive.  
+#'          Because of this, the confidence interval will
+#'          never cross the values for no effect 
+#'          (OR = 1, P = 0.5, or g = 0).
+#'          Because of this, the confidence interval range should not
+#'          be used for statistical inference for tables larger than 2 x 2. 
 #'          
 #'           When the reported statistics are close to their extremes,
 #'           or with small counts, 
@@ -76,9 +95,9 @@ cohenG =
     if(n==2){
       b  = x[1,2]
       c  = x[2,1]
-      OR = max(b/c, c/b)
+      OR = b/c
       OR = signif(OR, digits=digits)
-      P  = max(b/(b+c), c/(c+b))
+      P  = b/(b+c)
       P  = signif(P, digits=digits)
       g  = P - 0.5
       g  = signif(g, digits=digits)
@@ -108,7 +127,7 @@ cohenG =
                 Table = table(Input)
                 b  = Table[1,2]
                 c  = Table[2,1]
-                Stat = max(b/c, c/b)
+                Stat = b/c
                 return(Stat)}
     
     Boot = boot(Long, Function, R=R)
@@ -128,7 +147,7 @@ cohenG =
                 Table = table(Input)
                 b  = Table[1,2]
                 c  = Table[2,1]
-                Stat = max(b/(b+c), c/(c+b))
+                Stat = b/(b+c)
                 return(Stat)}
     
     Boot = boot(Long, Function, R=R)
