@@ -27,6 +27,10 @@
 #'           the absolute value of the phi statistic is the same as
 #'           Cramer's V.
 #'           
+#'           Because V is always positive, the confidence interval will
+#'           never cross zero. The confidence interval range should not
+#'           be used for statistical inference. 
+#'           
 #'           When V is close to 0 or very large,
 #'           or with small counts, 
 #'           the confidence intervals 
@@ -40,6 +44,8 @@
 #' @return A single statistic, Cramer's V.  
 #'         Or a small data frame consisting of Cramer's V,
 #'         and the lower and upper confidence limits.
+#'         In the data frame, \code{r} 
+#'         is just a duplicate of the Cramer's V value.
 #'         
 #' @examples
 #' ### Example with table
@@ -133,5 +139,5 @@ if(ci==TRUE){
 
 }
  if(ci==FALSE){names(CV)="Cramer V"; return(CV)}
- if(ci==TRUE){return(data.frame(r=CV, lower.ci=CI1, upper.ci=CI2))}  
+ if(ci==TRUE){return(data.frame(Cramer.V=CV, lower.ci=CI1, upper.ci=CI2, r=CV))}  
 }
