@@ -35,6 +35,10 @@
 #'           Currently, the function makes no provisions for \code{NA}
 #'           values in the data.  It is recommended that \code{NA}s be removed
 #'           beforehand.
+#'           
+#'           Because theta is always positive, the confidence interval will
+#'           never cross zero. The confidence interval range should not
+#'           be used for statistical inference. 
 #'
 #'           When theta is close to 0 or very large,
 #'           or with small counts in some cells,
@@ -191,7 +195,8 @@ if(ci==TRUE){
   CI1=signif(CI1, digits=digits)
   CI2=signif(CI2, digits=digits)
   
-  if(histogram==TRUE){hist(Boot$t[,1], col = "darkgray")}
+  if(histogram==TRUE){hist(Boot$t[,1], 
+                      col = "darkgray", xlab="theta", main="")}
   
 }
   
